<?php
/**
 * @file
 * Subthemer Settings UI Form
 * - OM Subthemes
 *
 */

/**
 * Menu callback for admin/settings/surveys/[node_type]/settings.
 */
function om_subthemer_settings(&$form_state, $type, $name) {

  drupal_set_title(t('Settings for %type nodes', array('%type' => check_plain($name))));

  $form['settings'] = array(
    '#type' => 'fieldset',
    '#title' => t(''),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
    '#tree' => TRUE,
  );
  $nid = 2;
  $result = db_query("SELECT cid, pid, tagid, type, iw, weight, nid 
                      FROM {om_subthemer_settings} 
                      WHERE nid = %d 
                      ORDER BY weight ASC", 
                      $nid);
  $layout = array();
  while ($record = db_fetch_object($result)) {
		$layout[] = _om_subthemer_settings($record);
  }
 
  $form['settings'] += $layout;  
  //dsm($form);
  $form['submit'] = array( '#type' => 'submit', '#value' => t('Save Settings'), );
  
  return $form;
}

/**
 * Layout Form
 *
 */
function _om_subthemer_settings($record) {
  
  $form['cid'] = array(
    '#type' => 'hidden',
    '#value' => $record->cid,
  );
  $form['nid'] = array(
    '#type' => 'hidden',
    '#value' => $record->nid,
  );  
  $form['pid'] = array(
    '#type' => 'textfield',
    '#title' => t('Parent'),
    '#return_value' => 1,
    '#default_value' => $record->pid,
    '#size' => 30,
  );
  $form['tagid'] = array(
    '#type' => 'textfield',
    '#title' => t('Tag ID'),
    '#return_value' => 1,
    '#default_value' => $record->tagid,
    '#size' => 30,
  );
  $form['type'] = array(
    '#type' => 'select',
    '#title' => t('Type'),
    '#return_value' => 1,
    '#default_value' => $record->type,
    '#options' => array('row' => 'Row', 'column' => 'Column'),
  );
  $form['iw'] = array(
    '#type' => 'checkbox',
    '#title' => t('Inner'),
    '#return_value' => 1,
    '#default_value' => $record->iw,
  );
  $form['weight'] = array(
    '#type' => 'select',
    '#title' => t('Type'),
    '#return_value' => 1,
    '#default_value' => $record->weight,
    '#options' => drupal_map_assoc(range(-50, 50)),
  );  
  $form['update'] = array(
    '#type' => ($form['cid']['#value']) ? 'checkbox' : 'hidden',
    '#title' => t('Update'),
    '#return_value' => 1,
    '#default_value' => 0,
    '#description' => t(''),
  );
  $form['delete'] = array(
    '#type' => ($form['cid']['#value']) ? 'checkbox' : 'hidden',
    '#title' => t('Delete'),
    '#return_value' => 1,
    '#default_value' => 0,
    '#description' => t(''),
  );    
  return $form;
}

/**
 * Implementation of theme_hook()
 * - View in table format
 *
 */
function theme_om_subthemer_settings($form) {
  $rows = array();
  $output = '';
  //dsm($form['layout']);
  foreach (element_children($form['layout']) as $key) {
    $row = array();
    // Strips labels
    $form['layout'][$key]['pid']['#title'] = '';
    $form['layout'][$key]['tagid']['#title'] = '';
    $form['layout'][$key]['type']['#title'] = '';
    $form['layout'][$key]['iw']['#title'] = '';
    $form['layout'][$key]['weight']['#title'] = '';
    $form['layout'][$key]['update']['#title'] = '';
    $form['layout'][$key]['delete']['#title'] = '';    
    $row[] = drupal_render($form['layout'][$key]['pid']);
    $row[] = drupal_render($form['layout'][$key]['tagid']);
    $row[] = drupal_render($form['layout'][$key]['type']);
    $row[] = drupal_render($form['layout'][$key]['iw']);
    $row[] = drupal_render($form['layout'][$key]['weight']);
    $row[] = drupal_render($form['layout'][$key]['update']);
    $row[] = drupal_render($form['layout'][$key]['delete']);    
    $rows[] = $row;
  }

  $header = array('pid', 'Tag ID', 'Type', 'Inner Wrapper', 'Weight', 'Update', 'Delete');

  // Header
  $form['layout']['#children'] = theme('table', $header, $rows);

  $output .= drupal_render($form);
  
  return $output;
}

/**
 * Layout Submit
 * table: cid, pid, tagid, type, iw, weight, nid
 */
function om_subthemer_settings_submit($form, $form_state) {
  $form_values = $form_state['values'];

  foreach ($form_values['layout'] as $layout) {
    if ($layout['cid'] && $layout['update']) {
      // Update an existing layout  
      db_query("UPDATE {om_subthemer_layout} SET pid = %d, tagid = '%s', type = '%s', iw = %d, weight = %d WHERE cid = %d", 
      $layout['pid'], $layout['tagid'], $layout['type'], $layout['iw'], $layout['weight'], $layout['cid']);
      drupal_set_message(t('The div (' . $layout['tagid'] . ') has been updated.'));
    }
    elseif ($layout['delete']) {
      // Delete an existing layout
      db_query("DELETE FROM {om_subthemer_layout} WHERE cid = %d", $layout['cid']);
      drupal_set_message(t('The div (' . $layout['tagid'] . ') has been deleted.'));
    }
    elseif (!$layout['cid'] && !empty($layout['tagid'])) {
      // Create a new layout
      db_query("INSERT INTO {om_subthemer_layout} (pid, tagid, type, iw, weight, nid) VALUES (%d, '%s', '%s', %d, %d, %d)", 
      $layout['pid'], $layout['tagid'], $layout['type'], $layout['iw'], $layout['weight'], $layout['nid']);
      drupal_set_message(t('The layout (' . $layout['tagid'] . ') has been added.'));
    }
    else {
      // If no condition is set, nothing should happen
    }
  }
}



