<?php
/**
 * @file
 * Writes OM Subtheme files
 *
 */


/**
 * Writes:
 * - index.html
 * - page.tpl.php
 * - subtheme.info
 * - subtheme.zip
 *
 */
function om_file_write($node) {	
	
	// create directory and index html file	
	$index_html = om_index_html_file($node);
  om_file_create($index_html, $node->om_user_files , 'index.html');

	// create directory and index php file	
	$index_php = om_index_php_file($node);
  om_file_create($index_php, $node->om_user_files , 'page.tpl.php');
  
  // previous info file must be deleted if the node title has changed
  om_info_delete($node);
    
	// create info file	
	$info = om_info_file($node);
	$info_name = strtolower(preg_replace('/ /','_', $node->title));
  om_file_create($info, $node->om_user_files , $info_name . '.info');
  
	// increase script timeout value
	ini_set("max_execution_time", 300);
	// create object
	$zip = new ZipArchive();

	// open archive
	if ($zip->open($node->om_user_files . '.zip', ZIPARCHIVE::OVERWRITE) !== TRUE) {
		die ("Could not open archive");
	}

	// pass it the directory to be processed
	$iterator = new RecursiveIteratorIterator(new RecursiveDirectoryIterator($node->om_user_files . '/'));
	// add each file found to the archive
	foreach ($iterator as $key => $value) {
	  //dsm($key);
	  // this is the way to delete the absolute path, /sites/...
	  $path = explode('/', $key);
	  while ($path[0] != $node->om_user_folder) {
	    array_shift($path);
	  }
	  // delete last path which is the user code u10001d10001
	  array_shift($path);
	  
	  // transform array to path and add the node title as the folder
	  $path_file = $info_name . '/' . implode('/', $path);
	  
	  // get file names
	  $file = array_reverse(explode('/', $key));
	  
	  // include only subtheme files
	  if ($file[0]!= '.' && $file[0] != '..' && $file[0] != 'index.html' && $file[0] != 'default.layout') {     
		  $zip->addFile(realpath($key),  $path_file) or die ("ERROR: Could not add file: $key");
		}
		
	}
	// close and save archive
	$zip->close();	
}


/**
 * Delete info file prior to creation, the user changed the node title
 *  
 * Add doctype, head, body tags to processed divs as html
 *
 */
function om_index_html_file($node) {
	$output = '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">';
	$output .= "\n" . '<html xmlns="http://www.w3.org/1999/xhtml">';
	$output .= "\n" . '<head>';
	$output .= "\n\t" . '<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />';
	$output .= "\n\t" . '<title>' . $node->title . ' - (' . $node->name . ')</title>';
	// TODO: create standard stylesheet
	$output .= "\n\t" . '<style media="all" type="text/css">
@import "/modules/node/node.css?J";
@import "/modules/system/defaults.css?J";
@import "/modules/system/system.css?J";
@import "/modules/system/system-menus.css?J";
@import "/modules/user/user.css?J";
@import "/sites/all/modules/admin_menu/admin_menu.css?J";
@import "/sites/all/modules/cck/theme/content-module.css?J";
@import "/sites/all/modules/ctools/css/ctools.css?J";
@import "/sites/all/modules/nice_menus/nice_menus.css?J";
@import "/sites/all/modules/nice_menus/nice_menus_default.css?J";
@import "/sites/all/modules/panels/css/panels.css?J";
@import "/sites/all/modules/views/css/views.css?J";
@import "/sites/test6.com/modules/om_subthemer/css/om_subthemer.css?J";
@import "/sites/all/themes/om/core/css/reset.css?J";
@import "/sites/all/themes/om/core/css/om.css?J";
</style>';

	$output .= "\n\t" . '<link href="' . base_path() . drupal_get_path('theme', 'om') . '/css/reset.css" rel="stylesheet" type="text/css" media="all" />';	
	$output .= "\n\t" . '<link href="' . base_path() . drupal_get_path('theme', 'om') . '/css/om.css" rel="stylesheet" type="text/css" media="all" />';	
	$output .= "\n\t" . '<link href="css/style.css" rel="stylesheet" type="text/css" media="all" />';
  $output .= "\n\t" . '<script src="js/script.js" type="text/javascript" ></script>';
  $output .= "\n" . '</head>';
	$output .= "\n" . '<body>' . "\n";
	$output .= $node->om_layout_html_content;
  $output .= "\n" . '<div id="legal"><a href="http://www.drupal.org/project/om_subthemer">OM SubThemer</a> ' . date('d-m-Y h:i:s A') . ' | V6.x-1.x | by <a href="http://www.danielhonrade.com">Daniel Honrade</a></div>';
	$output .= "\n\n" . '</body>';
	$output .= "\n" . '</html>';
	return $output;
}


/**
 * Delete info file prior to creation, the user changed the node title
 *  
 * Adds doctype, head, body tags to processed divs as php
 *
 */
function om_index_php_file($node) {
  $output = '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">';
  $output .= "\n" . '<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php print $language->language ?>" lang="<?php print $language->language ?>" dir="<?php print $language->dir ?>">';
  $output .= "\n" . '<head>';
  $output .= "\n\t" . '<?php print $head; ?>';
  $output .= "\n\t" . '<title><?php print $head_title; ?></title>';
  $output .= "\n\t" . '<?php print $styles; ?>';
  $output .= "\n\t" . '<!--[if IE  ]><?php print om_get_ie_styles(\'ie\'); ?><![endif]-->';
  $output .= "\n\t" . '<!--[if IE 6]><?php print om_get_ie_styles(\'ie6\'); ?><![endif]-->';
  $output .= "\n\t" . '<!--[if IE 7]><?php print om_get_ie_styles(\'ie7\'); ?><![endif]-->';
  $output .= "\n\t" . '<!--[if IE 8]><?php print om_get_ie_styles(\'ie8\'); ?><![endif]-->';
  $output .= "\n\t" . '<!--[if IE 9]><?php print om_get_ie_styles(\'ie9\'); ?><![endif]-->';
  $output .= "\n\t" . '<?php print $scripts; ?>';
  $output .= "\n\t" . '<script type="text/javascript"><?php /* Needed to avoid Flash of Unstyled Content in IE */ ?> </script>';
  $output .= "\n" . '</head>';
  $output .= "\n" . '<body class="<?php print $body_classes; ?>">' . "\n";
	$output .= $node->om_layout_php_content;
  $output .= "\n" . '<?php print $closure; ?>';
  $output .= "\n\n" . '</body>';
	$output .= "\n" . '</html>';
	return $output;
}


/**
 * Delete info file prior to creation, the user changed the node title
 * - file write
 *
 */
function om_info_delete($node) {

  $dir = $node->om_user_files;
  $info_file = scandir($dir);
    
  //array_shift($files); // removes '.'
  //array_shift($files); // removes '..'
    
  foreach ($info_file as $file) {
    $file_name_array = explode('.', $file);
    $file = $dir . '/' . $file;
      if ($file_name_array[1] == 'info') unlink($file);
  }
}


/**
 * Info file
 * 
 * - adds/updates regions and OM Subtheme name
 *
 */
function om_info_file($node) {
	global $om_regions;
	
  $output = '';
  $output .= '; name, description, screenshot, version - these are necessary for theme list';
	$output .= "\n";
  $output .= "\n" . 'name        = ' . $node->title . ' - Created by ' . ucwords($node->name);
  $output .= "\n" . 'description = "This a subtheme of OM Base Theme. For more info, read the <a href="http://drupal.org/node/1056254">OM Theme Documentation</a>"';
  $output .= "\n" . 'screenshot  = "screenshot.png"';
	$output .= "\n";
  $output .= "\n" . 'base theme = om';
	$output .= "\n";
  $output .= "\n" . '; compatibilities';
  $output .= "\n" . 'core        = "6.x"';
  $output .= "\n" . 'engine      = phptemplate';
	$output .= "\n";
  $output .= "\n" . '; default stylesheets';
	$output .= "\n";
  $output .= "\n" . 'stylesheets[all][] = "css/style.css"';
	$output .= "\n";
  $output .= "\n" . '; jquery scripts';
  $output .= "\n" . 'scripts[]       = "js/script.js"';
	$output .= "\n";
  $output .= "\n" . '; default regions, on the left inside the brackets'; 
  $output .= "\n" . '; are the variable names used in page.tpl.php,';
  $output .= "\n" . '; on right side are the names necessary for blocks list';
	$output .= "\n";
	foreach($om_regions as $key => $region) {
		$output .= "\n" . 'regions[' . strtolower(preg_replace('/ /', '_', $region)) . '] = ' . $region;
	}
	$output .= "\n";
  $output .= "\n" . '; default features for theme settings';
  $output .= "\n" . 'features[] = logo';
  $output .= "\n" . 'features[] = name';
  $output .= "\n" . 'features[] = slogan';
  $output .= "\n" . 'features[] = mission';
  $output .= "\n" . 'features[] = node_user_picture';
  $output .= "\n" . 'features[] = comment_user_picture';
  $output .= "\n" . 'features[] = search';
  $output .= "\n" . 'features[] = favicon';
  $output .= "\n" . 'features[] = primary_links';
  $output .= "\n" . 'features[] = secondary_links';
  $output .= "\n" . 'features[] = breadcrumbs';	
	$output .= "\n";
	return $output;
}
